**Example 1: 停止Notebook实例**



Input: 

```
tccli tione StopNotebookInstance --cli-unfold-argument  \
    --NotebookInstanceName api_test
```

Output: 
```
{
    "Response": {
        "RequestId": "fe8f6fd2-1f51-4699-b19d-efa8b6efde8a"
    }
}
```

